@@ -4,7 +4,7 @@ use Exporter 'import';
 use Digest::MD5 qw(md5_hex);
 
 use 5.010;
-our $VERSION = '1.611'; # ==> ALSO update the version in the pod text below!
+our $VERSION = '1.612'; # ==> ALSO update the version in the pod text below!
 
 # loaded modules
 our %TAG_HANDLERS;
@@ -25,7 +25,6 @@ require XSLoader;
 XSLoader::load('DTL::Fast', $VERSION);
 
 our $RUNTIME_CACHE;
-our $SERIALIZED_CACHE;
 
 our @EXPORT_OK;
 
@@ -104,40 +103,29 @@ sub read_template
     
     my $cache_key = _get_cache_key( $template_name, %kwargs );
 
-    $SERIALIZED_CACHE //= DTL::Fast::Cache::Serialized->new();
-    
     if( 
         $kwargs{'no_cache'}
-        or not defined ( $template = $SERIALIZED_CACHE->get($cache_key))   # runtime serialized cache reading
+        or not exists $kwargs{'cache'} 
+        or not $kwargs{'cache'}
+        or not $kwargs{'cache'}->isa('DTL::Fast::Cache')
+        or not defined ($template = $kwargs{'cache'}->get($cache_key))
     )
     {
-        if( 
-            $kwargs{'no_cache'}
-            or not exists $kwargs{'cache'} 
-            or not $kwargs{'cache'}
-            or not $kwargs{'cache'}->isa('DTL::Fast::Cache')
-            or not defined ($template = $kwargs{'cache'}->get($cache_key))
-        )
+        ($template, $template_path) = _read_file($template_name, $kwargs{'dirs'});
+        
+        if( defined $template )
         {
-            ($template, $template_path) = _read_file($template_name, $kwargs{'dirs'});
-            
-            if( defined $template )
-            {
-                $kwargs{'file_path'} = $template_path;
-                $template = DTL::Fast::Template->new( $template, %kwargs);
-        
-                $kwargs{'cache'}->put( $cache_key, $template )
-                    if 
-                        defined $template
-                        and exists $kwargs{'cache'}
-                        and $kwargs{'cache'}
-                        and $kwargs{'cache'}->isa('DTL::Fast::Cache')
-                    ;
-            }
+            $kwargs{'file_path'} = $template_path;
+            $template = DTL::Fast::Template->new( $template, %kwargs);
+    
+            $kwargs{'cache'}->put( $cache_key, $template )
+                if 
+                    defined $template
+                    and exists $kwargs{'cache'}
+                    and $kwargs{'cache'}
+                    and $kwargs{'cache'}->isa('DTL::Fast::Cache')
+                ;
         }
-        
-        $SERIALIZED_CACHE->put($cache_key, $template)
-            if defined $template;
     }
     
     if( defined $template )
@@ -333,8 +321,6 @@ sub preload_operators
 
 require DTL::Fast::Template;
 require DTL::Fast::Cache::Runtime;
-require DTL::Fast::Cache::Serialized;
-
 
 1;
 
@@ -345,7 +331,7 @@ DTL::Fast - Perl implementation of Django templating language.
 
 =head1 VERSION
 
-Version 1.611
+Version 1.612
 
 =head1 SYNOPSIS
 
@@ -539,6 +525,10 @@ Preloads all registered operators modules. Mostly for debugging purposes or pers
 
 This module supports almost all built-in tags documented on L<official Django site|https://docs.djangoproject.com/en/1.7/ref/templates/builtins/#built-in-tag-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
 
+=head3 block_super
+
+New tag for using with inheritance in order to render a parent block. In Django you are using C<{{ block.super }}> which is also currently supported, but depricated and will be removed in future versions.
+
 =head3 firstofdefined
 
 New tag, that works like C<firstof> tag, but checks if value is defined (not true)
@@ -623,6 +613,8 @@ To do...
 
 =over
 
+=item * C<{{ block.super }}> construction is currently supported, but depricated in favor of C<{% block_super %}> tag.
+
 =item * Django's setting C<ALLOWED_INCLUDE_ROOTS> should be passed to tempalte constructor/getter as C<ssi_dirs> argument.
 
 =item * C<csrf_token> tag is not implemented, too well connected with Django.
@@ -655,12 +647,6 @@ May be some of this features implemented in Django itself. Let me know about it.
 
 =item * filters may accept several arguments, and context variables can be used in them, like {{ var|filter1:var2:var3:...:varn }}
 
-=item * C<numberformat> - new filter. Formats number like C<12 345 678.9999999> 
-
-=item * C<strftime> - new filter. Formats time using L<C<Date::Format>> module, which is using C functions C<strftime> and C<ctime>.
-
-=item * C<firstofdefined> - new tag, that works like C<firstof> tag, but checks if value is defined (not true)
-
 =item * C<defined> logical operator. In logical constructions you may use C<defined> operator, which works exactly like perl's C<defined>
 
 =item * alternatively, in logical expresisons you may compare (==,!=) value to C<undef> or C<None> which are synonims
@@ -736,10 +722,10 @@ Template parsing permormance with software cache wiping on each iteration:
 
     Benchmark: timing 5000 iterations of DTL::Fast  , Dotiac::DTL...
     
-    DTL::Fast  :  3 wallclock secs ( 2.47 usr +  1.05 sys =  3.51 CPU) @ 1424.10/s (n=5000)
-    Dotiac::DTL: 44 wallclock secs (21.86 usr + 20.39 sys = 42.25 CPU) @ 118.36/s (n=5000)
+    DTL::Fast  :  5 wallclock secs ( 4.52 usr +  0.16 sys =  4.68 CPU) @ 1068.45/s (n=5000)
+    Dotiac::DTL: 41 wallclock secs (38.87 usr +  2.14 sys = 41.01 CPU) @ 121.93/s (n=5000)
 
-C<DTL::Fast> parsing templates 12 times faster, than L<C<Dotiac::DTL>>.
+C<DTL::Fast> parsing templates 8.7 times faster, than L<C<Dotiac::DTL>>.
 
 To run this test, you need to alter L<C<Dotiac::DTL>> module and change declaration of C<my %cache;> to C<our %cache;>. 
     
@@ -747,10 +733,10 @@ Rendering of pre-compiled template (software cache):
 
     Benchmark: timing 3000 iterations of DTL::Fast  , Dotiac::DTL...
     
-    DTL::Fast  : 17 wallclock secs (13.46 usr +  3.87 sys = 17.33 CPU) @ 173.09/s (n=3000)
-    Dotiac::DTL: 18 wallclock secs (17.38 usr +  0.00 sys = 17.38 CPU) @ 172.63/s (n=3000)
+    DTL::Fast  : 45 wallclock secs (44.48 usr +  0.36 sys = 44.84 CPU) @ 66.90/s (n=3000)
+    Dotiac::DTL: 53 wallclock secs (53.02 usr +  0.51 sys = 53.52 CPU) @ 56.05/s (n=3000)
 
-Tests shows, that C<DTL::Fast> works a bit faster, than L<C<Dotiac::DTL>> in persistent environment.
+Tests shows, that C<DTL::Fast> works a 20% faster, than L<C<Dotiac::DTL>> in persistent environment.
 
 =head2 CGI
 
@@ -758,10 +744,10 @@ This test rendered test template many times by external script, invoked via C<sy
 
     Benchmark: timing 300 iterations of Dotiac render     , Fast cached render, Fast render
     
-    Dotiac render     : 40 wallclock secs ( 0.11 usr +  0.40 sys =  0.51 CPU) @ 583.66/s (n=300)
-    Fast render       : 55 wallclock secs ( 0.06 usr +  0.42 sys =  0.48 CPU) @ 619.83/s (n=300)
+    DTL::Fast  : 41 wallclock secs ( 0.01 usr  0.12 sys + 37.09 cusr  4.03 csys = 41.25 CPU) @  7.27/s (n=300)
+    Dotiac::DTL: 49 wallclock secs ( 0.04 usr  0.09 sys + 44.30 cusr  4.45 csys = 48.88 CPU) @  6.14/s (n=300)
 
-Tests shows, that C<DTL::Fast> works 40% slower, than L<C<Dotiac::DTL>> in CGI environment.
+Tests shows, that C<DTL::Fast> works 18% faster, than L<C<Dotiac::DTL>> in CGI environment.
 
 =head2 DTL::Fast steps performance
 
